import argparse
import requests
import base64

def generate_token(username, app_password):
    token = base64.b64encode(f"{username}:{app_password}".encode()).decode()
    return token

def read_content(file_path):
    with open(file_path, 'r', encoding='utf-8') as file:
        return file.read()

def publish_post(args):
    token = generate_token(args.username, args.app_password)
    content = read_content(args.content_file)
    url = f"{args.site}/wp-json/wp/v2/posts"
    headers = {"Authorization": f"Basic {token}"}
    data = {"title": args.title, "content": content, "status": "publish"}

    if args.categories:
        data["categories"] = [int(category_id.strip()) for category_id in args.categories.split(',')]
    if args.tags:
        data["tags"] = args.tags.split(',')

    response = requests.post(url, headers=headers, json=data)
    if response.status_code == 201:
        print(f"Пост успешно опубликован: {response.json()['link']}")
    else:
        print(f"Ошибка: {response.content}")

def main():
    parser = argparse.ArgumentParser(description="Publish a post to WordPress via REST API")
    parser.add_argument("--site", required=True, help="URL to your WordPress site")
    parser.add_argument("--username", required=True, help="Username for WordPress")
    parser.add_argument("--app_password", required=True, help="Application password for WordPress")
    parser.add_argument("--title", required=True, help="Title of the post")
    parser.add_argument("--content_file", required=True, help="Path to the file with post content")
    parser.add_argument("--categories", help="Comma-separated list of category IDs")
    parser.add_argument("--tags", help="Comma-separated list of tag IDs")

    args = parser.parse_args()
    publish_post(args)

if __name__ == "__main__":
    main()
